from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SegmentRequest(_message.Message):
    __slots__ = ("input",)
    INPUT_FIELD_NUMBER: _ClassVar[int]
    input: str
    def __init__(self, input: _Optional[str] = ...) -> None: ...

class SegmentResponse(_message.Message):
    __slots__ = ("output",)
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    output: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, output: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc_py_gen/dependency.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'grpc_py_gen/dependency.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgrpc_py_gen/dependency.proto\x12\ndependency\"8\n\nDependency\x12\x0c\n\x04word\x18\x01 \x01(\t\x12\x0f\n\x07gov_idx\x18\x02 \x01(\x05\x12\x0b\n\x03rel\x18\x03 \x01(\t\">\n\x0e\x44\x65pendencyList\x12,\n\x0c\x64\x65pendencies\x18\x01 \x03(\x0b\x32\x16.dependency.Dependency\"6\n\x18ParseDependenciesRequest\x12\x0c\n\x04lang\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"P\n\x19ParseDependenciesResponse\x12\x33\n\x0f\x64\x65pendency_list\x18\x01 \x03(\x0b\x32\x1a.dependency.DependencyList2u\n\x11\x44\x65pendencyService\x12`\n\x11ParseDependencies\x12$.dependency.ParseDependenciesRequest\x1a%.dependency.ParseDependenciesResponseB-Z+github.com/citadel2024/word_segment_grpc_gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_py_gen.dependency_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/citadel2024/word_segment_grpc_go'
  _globals['_DEPENDENCY']._serialized_start=44
  _globals['_DEPENDENCY']._serialized_end=100
  _globals['_DEPENDENCYLIST']._serialized_start=102
  _globals['_DEPENDENCYLIST']._serialized_end=164
  _globals['_PARSEDEPENDENCIESREQUEST']._serialized_start=166
  _globals['_PARSEDEPENDENCIESREQUEST']._serialized_end=220
  _globals['_PARSEDEPENDENCIESRESPONSE']._serialized_start=222
  _globals['_PARSEDEPENDENCIESRESPONSE']._serialized_end=302
  _globals['_DEPENDENCYSERVICE']._serialized_start=304
  _globals['_DEPENDENCYSERVICE']._serialized_end=421
# @@protoc_insertion_point(module_scope)



__all__ = [
    "dependency_pb2",
    "dependency_pb2_grpc",
    "ner_pb2",
    "ner_pb2_grpc",
    "segment_pb2",
    "segment_pb2_grpc",
]

# Keep the version in sync with grpc_py_gen/pyproject.toml.
__version__ = "0.1.0"



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Entity(_message.Message):
    __slots__ = ("type", "start", "end", "prob", "span")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    PROB_FIELD_NUMBER: _ClassVar[int]
    SPAN_FIELD_NUMBER: _ClassVar[int]
    type: str
    start: int
    end: int
    prob: float
    span: str
    def __init__(self, type: _Optional[str] = ..., start: _Optional[int] = ..., end: _Optional[int] = ..., prob: _Optional[float] = ..., span: _Optional[str] = ...) -> None: ...

class EntityList(_message.Message):
    __slots__ = ("entities",)
    ENTITIES_FIELD_NUMBER: _ClassVar[int]
    entities: _containers.RepeatedCompositeFieldContainer[Entity]
    def __init__(self, entities: _Optional[_Iterable[_Union[Entity, _Mapping]]] = ...) -> None: ...

class NerRequest(_message.Message):
    __slots__ = ("text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    text: str
    def __init__(self, text: _Optional[str] = ...) -> None: ...

class NerResponse(_message.Message):
    __slots__ = ("entity_list",)
    ENTITY_LIST_FIELD_NUMBER: _ClassVar[int]
    entity_list: EntityList
    def __init__(self, entity_list: _Optional[_Union[EntityList, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc_py_gen/segment.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'grpc_py_gen/segment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19grpc_py_gen/segment.proto\x12\x11word_segmentation\"\x1f\n\x0eSegmentRequest\x12\r\n\x05input\x18\x01 \x01(\t\"!\n\x0fSegmentResponse\x12\x0e\n\x06output\x18\x01 \x03(\t2d\n\x10WordSegmentation\x12P\n\x07Segment\x12!.word_segmentation.SegmentRequest\x1a\".word_segmentation.SegmentResponseB-Z+github.com/citadel2024/word_segment_grpc_gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_py_gen.segment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/citadel2024/word_segment_grpc_go'
  _globals['_SEGMENTREQUEST']._serialized_start=48
  _globals['_SEGMENTREQUEST']._serialized_end=79
  _globals['_SEGMENTRESPONSE']._serialized_start=81
  _globals['_SEGMENTRESPONSE']._serialized_end=114
  _globals['_WORDSEGMENTATION']._serialized_start=116
  _globals['_WORDSEGMENTATION']._serialized_end=216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: grpc_py_gen/ner.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'grpc_py_gen/ner.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15grpc_py_gen/ner.proto\x12\x03ner\"N\n\x06\x45ntity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0c\n\x04prob\x18\x04 \x01(\x02\x12\x0c\n\x04span\x18\x05 \x01(\t\"+\n\nEntityList\x12\x1d\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x0b.ner.Entity\"\x1a\n\nNerRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\"3\n\x0bNerResponse\x12$\n\x0b\x65ntity_list\x18\x01 \x01(\x0b\x32\x0f.ner.EntityList2B\n\nNerService\x12\x34\n\x0f\x45xtractEntities\x12\x0f.ner.NerRequest\x1a\x10.ner.NerResponseB-Z+github.com/citadel2024/word_segment_grpc_gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpc_py_gen.ner_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/citadel2024/word_segment_grpc_go'
  _globals['_ENTITY']._serialized_start=30
  _globals['_ENTITY']._serialized_end=108
  _globals['_ENTITYLIST']._serialized_start=110
  _globals['_ENTITYLIST']._serialized_end=153
  _globals['_NERREQUEST']._serialized_start=155
  _globals['_NERREQUEST']._serialized_end=181
  _globals['_NERRESPONSE']._serialized_start=183
  _globals['_NERRESPONSE']._serialized_end=234
  _globals['_NERSERVICE']._serialized_start=236
  _globals['_NERSERVICE']._serialized_end=302
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Dependency(_message.Message):
    __slots__ = ("word", "gov_idx", "rel")
    WORD_FIELD_NUMBER: _ClassVar[int]
    GOV_IDX_FIELD_NUMBER: _ClassVar[int]
    REL_FIELD_NUMBER: _ClassVar[int]
    word: str
    gov_idx: int
    rel: str
    def __init__(self, word: _Optional[str] = ..., gov_idx: _Optional[int] = ..., rel: _Optional[str] = ...) -> None: ...

class DependencyList(_message.Message):
    __slots__ = ("dependencies",)
    DEPENDENCIES_FIELD_NUMBER: _ClassVar[int]
    dependencies: _containers.RepeatedCompositeFieldContainer[Dependency]
    def __init__(self, dependencies: _Optional[_Iterable[_Union[Dependency, _Mapping]]] = ...) -> None: ...

class ParseDependenciesRequest(_message.Message):
    __slots__ = ("lang", "text")
    LANG_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    lang: str
    text: str
    def __init__(self, lang: _Optional[str] = ..., text: _Optional[str] = ...) -> None: ...

class ParseDependenciesResponse(_message.Message):
    __slots__ = ("dependency_list",)
    DEPENDENCY_LIST_FIELD_NUMBER: _ClassVar[int]
    dependency_list: _containers.RepeatedCompositeFieldContainer[DependencyList]
    def __init__(self, dependency_list: _Optional[_Iterable[_Union[DependencyList, _Mapping]]] = ...) -> None: ...
